@@ -96,7 +96,7 @@ class ReportLabPDFBuilder:
 
 class Row:
     def __init__(self, columns, line=None, grid=None, background_color=None, text_color=None, full_width=False,
-                 align=TA_LEFT):
+                 align=TA_LEFT, valign=None):
         self.columns = columns
         self.line = line
         self.grid = grid
@@ -104,6 +104,7 @@ class Row:
         self.text_color = text_color
         self.align = align
         self.full_width = full_width
+        self.valign = valign  # TOP, MIDDLE, BOTTOM
 
     def get_number_of_columns(self):
         return len(self.columns)
@@ -111,8 +112,8 @@ class Row:
 
 class Column:
 
-    def __init__(self, content, line=None, grid=None, background_color=None, text_color=None, image_width=50,
-                 image_height=50, align=TA_LEFT):
+    def __init__(self, content='', line=None, grid=None, background_color=None, text_color=None, image_width=50,
+                 image_height=50, align=TA_LEFT, valign=None):
         """
 
         :param content: This variable's data will be passed into the Reportlab's Paragraph Class, or if its BytesIO
@@ -132,6 +133,7 @@ class Column:
         self.image_width = image_width
         self.image_height = image_height
         self.align = align
+        self.valign = valign  # TOP, MIDDLE, BOTTOM
 
 
 class Grid:
@@ -251,7 +253,19 @@ def pfd_table_builder(data, fonts=None):
                 # SPAN
                 if row_obj.full_width:
                     table_styles.add('SPAN', (col_ctr, row_ctr), (-1, row_ctr))
-
+                # VALIGN
+                apply_style = False
+                valign = None
+                if col_obj.valign:
+                    apply_style = True
+                    valign = col_obj.valign
+                    print('COL:', valign)
+                elif row_obj.valign:
+                    apply_style = True
+                    valign = row_obj.valign
+                    print('ROW:', valign)
+                if apply_style:
+                    table_styles.add('VALIGN', (col_ctr, row_ctr), (col_ctr, row_ctr), valign)
     t = Table(table_data)
     t.setStyle(table_styles)
     return t
